@@ -624,16 +624,38 @@ class OracleSourceConnector(C8Connector):
    def config(self) -> list[ConfigProperty]:
       """Get configuration parameters for the connector."""
       return [
-         ConfigProperty('host', 'string', True),
-         ConfigProperty('port', 'integer', True),
-         ConfigProperty('user', 'string', True),
-         ConfigProperty('password', 'string', True),
-         ConfigProperty('default_replication_method', 'string', True),
-         ConfigProperty('filter_schemas', 'string', False),
-         ConfigProperty('service_name', 'string', False),
-         ConfigProperty('pdb_name', 'string', False),
-         ConfigProperty('multitenant', 'boolean', False),
-         ConfigProperty('scn_window_size', 'integer', False),
+         ConfigProperty('host', 'string', True, False,
+                        description="Oracle DB host",
+                        example="58.13.14.19"),
+         ConfigProperty('port', 'integer', True, False,
+                        description="Oracle DB port",
+                        example="1521"),
+         ConfigProperty('user', 'string', True, False,
+                        description="Oracle DB username",
+                        example="macrometa"),
+         ConfigProperty('password', 'string', True, False,
+                        description="Oracle DB user's password",
+                        example="oracle"),
+         ConfigProperty('default_replication_method', 'string', True, False,
+                        description="Default replication method to use when no one is provided in the "
+                                    "catalog (Values: LOG_BASED, INCREMENTAL or FULL_TABLE).",
+                        example="LOG_BASED"),
+         ConfigProperty('filter_schemas', 'string', False, False,
+                        description="Scan only the specified comma-separated schemas to improve the "
+                                    "performance of data extraction",
+                        example="C##CUSTOMERS"),
+         ConfigProperty('service_name', 'string', True, False,
+                        description="Oracle DB service name",
+                        example="ORCLCDB"),
+         ConfigProperty('pdb_name', 'string', False, False,
+                        description="Oracle portable db name",
+                        example="ORCLPDB1"),
+         ConfigProperty('multitenant', 'boolean', False, False,
+                        description="Is Oracle DB is multi tennat or not",
+                        example="true"),
+         ConfigProperty('scn_window_size', 'integer', False, False,
+                        description="Oracle scn window for logminer replication",
+                        example="1000"),
       ]
 
    def capabilities(self) -> list[str]:
